;; Generated package description from parser-generator.el  -*- no-byte-compile: t -*-
(define-package "parser-generator" "0.2.7.0.20251221.222232" "Parser Generator library" '((emacs "26")) :commit "5015e4fd92f9c33d3c6f0a50d0c802efbcb95ec0" :authors '(("Christian Johansson" . "christian@cvj.se")) :maintainer '("Christian Johansson" . "christian@cvj.se") :keywords '("tools" "convenience") :url "https://github.com/cjohansson/emacs-parser-generator")
